#
# spec file for package python-peewee
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-peewee
Version:        3.7.1
Release:        lp152.3.6
Summary:        An expressive ORM that supports multiple SQL backends
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/coleifer/peewee
Source:         https://files.pythonhosted.org/packages/source/p/peewee/peewee-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
BuildRequires:  pkgconfig(sqlite3)
%python_subpackages

%description
An expressive ORM that supports PostgreSQL, MySQL and SQLite.

%prep
%setup -q -n peewee-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone %{buildroot}%{_bindir}/pwiz.py
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.rst TODO.rst
%{_bindir}/pwiz.py-%{python_bin_suffix}
%python3_only %{_bindir}/pwiz.py
%{python_sitearch}/*

%changelog
* Mon Oct  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Update to 3.7.1:
  * Added table_settings model Meta option, which should be a list
    of strings specifying additional options for CREATE TABLE, which
    are placed after the closing parentheses.
  * Allow specification of on_update and on_delete behavior for
    many-to-many relationships when using ManyToManyField.
  * Fixed incorrect SQL generation for Postgresql ON CONFLICT clause
    when the conflict_target is a named constraint (rather than an
    index expression). This introduces a new keyword-argument to the
    on_conflict() method: conflict_constraint, which is currently only
    supported by Postgresql. Refs issue #1737.
  * Fixed incorrect SQL for sub-selects used on the right side of IN
    expressions. Previously the query would be assigned an alias, even
    though an alias was not needed.
  * Fixed incorrect SQL generation for Model indexes which contain SQL
    functions as indexed columns.
  * Fixed bug in the generation of special queries used to perform
    operations on SQLite FTS5 virtual tables.
  * Allow frozenset to be correctly parameterized as a list of values.
  * Allow multi-value INSERT queries to specify columns as a list of
    strings.
  * Support CROSS JOIN for model select queries.
* Sat Jul 28 2018 jengelh@inai.de
- Add missing "that".
* Thu Jul 19 2018 mcepl@suse.com
- Update to 3.6.4:
  - bugfixes
  - works with python 3.7.0
  - Support for specifying ROWS or RANGE window frame types.
  - Add APIs for user-defined window functions if using
    pysqlite3 and sqlite 3.25.0 or newer.
  - TimestampField now uses 64-bit integer data-type for
    storage.
  - Added support to pwiz and playhouse.reflection to enable
    generating models from VIEWs.
  - Added lower-level database API for introspecting VIEWs.
  - Revamped continuous integration setup for better coverage,
    including 3.7 and 3.8-dev.
  - Allow building C extensions even if Cython is not
    installed, by distributing pre-generated C source files.
- Fixes tests
* Wed Jul  4 2018 avvissu@yandex.by
- Update to 3.5.2:
  * New guide to using window functions in Peewee.
  * New and improved table name auto-generation.
  * Allow passing single fields/columns to window function
    order_by and partition_by arguments.
  * Support for FILTER (WHERE...) clauses with window functions
    and aggregates.
  * Added IdentityField class suitable for use with Postgres 10's
    new identity column type.
  * Fixed bug creating indexes on tables that are in attached
    databases (SQLite).
  * Fixed obscure bug when using prefetch() and ModelAlias to
    populate a back-reference related model.
- Change in 3.5.1:
  * New documentation for working with relationships in Peewee.
  * Improved tests and documentation for MySQL upsert functionality.
  * Allow database parameter to be specified with ModelSelect.get()
    method. For discussion, see #1620.
  * Add QualifiedNames helper to peewee module exports.
  * Add temporary= meta option to support temporary tables.
  * Allow a Database object to be passed to constructor of
    DataSet helper.
* Sat Jun 23 2018 avvissu@yandex.by
- Update to 3.5.0:
  * see: /usr/share/package/python-peewee/CHANGELOG.md
- Build with dependencies: sqlite3, cython
- Build with python3 and python2 (singlespec)
- Drop the noarch package (arch-independent-package-contains-binary-or-object)
- Spec file cleanup
* Fri Aug 14 2015 i@marguerite.su
- update version 2.6.3
  * read https://github.com/coleifer/peewee/releases
* Mon Apr 28 2014 i@marguerite.su
- update version 2.2.3
  * New migrations module
  * Added a return value to Model.save() indicating number of rows
    affected.
  * Added a date_trunc() method that works for Sqlite.
  * Added a Model.sqlall() class-method to return all the SQL to
    generate the model/indices.
  * bugfixes
* Sun Apr 20 2014 i@marguerite.su
- initial version 2.2.2
  * see https://github.com/coleifer/peewee/commits/master for details
